getBuffer method

Uint8List getBuffer(
  1. int position,
  2. int length
)

Extracts a portion of the buffer as a new Uint8List.

position Starting position in the buffer length Number of bytes to extract Returns a sublist view of the buffer data

Implementation

Uint8List getBuffer(int position, int length) {
  assert(position >= 0, "position $position < 0");
  assert(position + length <= _bufferData.length, "position $position + length $length > ${_bufferData.length}");
  return _bufferData.sublist(position, position + length);
}