offset property
int
get
offset
The current offset in the underlying file which denotes the start of the _bufferData or null if unknown
Implementation
int get offset => _offset;
The current offset in the underlying file which denotes the start of the _bufferData or null if unknown
int get offset => _offset;