ReadbufferSource class abstract

An abstract interface for a source of binary data from which a Readbuffer can be created.

This class provides a common API for reading data from different sources, such as a physical file or an in-memory byte array.

Implementers

Constructors

ReadbufferSource()

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputStream → Stream<List<int>>
Returns the content of the data source as a stream.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Closes the underlying data source and releases any associated resources.
freeRessources() → Future<void>
Frees resources that cannot be transferred to an isolate.
getPosition() → int
Returns the current read position in the data source.
length() → Future<int>
Returns the total length of the data source in bytes.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readFromFile(int length) → Future<Readbuffer>
Reads a block of data of the given length from the current position.
readFromFileAt(int position, int length) → Future<Readbuffer>
Reads a block of data of the given length from a specific position.
readFromFileAtMax(int position, int maxLength) → Future<Readbuffer>
Reads a block of data of the given length from a specific position.
setPosition(int position) → Future<void>
Sets the current read position in the data source.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited