readFromFileAtMax abstract method
Reads a block of data of the given length from a specific position.
Returns a Readbuffer containing the read data.
Implementation
Future<Readbuffer> readFromFileAtMax(int position, int maxLength);
Reads a block of data of the given length from a specific position.
Returns a Readbuffer containing the read data.
Future<Readbuffer> readFromFileAtMax(int position, int maxLength);