ILatLong class abstract

An interface for a geographical point with latitude and longitude coordinates.

Implementers

Constructors

ILatLong()

Properties

hashCode → int
The hash code for this object.
no setterinherited
latitude → double
The latitude of this point in degrees.
no setter
longitude → double
The longitude of this point in degrees.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited