Mappoint class

An immutable pair of absolute double coordinates in map pixels.

0/0 represents the upper-left corner of the complete map (latitude 90, longitude -180).

Constructors

Mappoint(double x, double y)
Creates a new Mappoint.
const
Mappoint.zero()
Creates a new Mappoint at the origin (0,0).
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → double
The x coordinate of this point in pixels. Positive values points towards the right side of the screen.
final
y → double
The y coordinate of this point in pixels. Positive values points to the bottom of the screen.
final

Methods

distance(Mappoint point) → double
Calculates the Euclidean distance from this point to the given point.
distanceSquared(Mappoint point) → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offset(Mappoint reference) → MappointRelative
Creates a MappointRelative that represents the offset from a given reference point.
offsetAbsolute(double dx, double dy) → Mappoint
Creates a new Mappoint that is offset by the given dx and dy values.
radiansTo(Mappoint other) → double
Calculates the angle in radians from this point to the other point.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override