MicroLatLong class

Implemented types

Constructors

MicroLatLong(int _latitude, int _longitude)
MicroLatLong.fromDegrees(double latitude, double longitude)

Properties

hashCode int
The hash code for this object.
no setterinherited
latitude double
The latitude of this point in degrees.
no setteroverride
latitudeMicrodegrees int
no setter
longitude double
The longitude of this point in degrees.
no setteroverride
longitudeMicrodegrees int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited