NanoLatLong class

Implemented types

Constructors

NanoLatLong.fromDegrees(double latitude, double longitude)
NanoLatLong.fromNano(int _latitude, int _longitude)

Properties

hashCode int
The hash code for this object.
no setterinherited
latitude double
The latitude of this point in degrees.
no setteroverride
latitudeNanodegrees int
no setter
longitude double
The longitude of this point in degrees.
no setteroverride
longitudeNanodegrees int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited