PointOfInterest class

An immutable container for all data associated with a single Point of Interest (POI).

Constructors

PointOfInterest(int layer, TagCollection tags, ILatLong position)
Creates a new PointOfInterest.
PointOfInterest.simple(ILatLong position)

Properties

hashCode → int
The hash code for this object.
no setteroverride
layer → int
The layer of this POI + 5 (to avoid negative values). Valid values are 0 to 15
final
position → ILatLong
The position of this POI.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → TagCollection
The tags of this POI.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
toStringWithoutNames() → String
Returns a string representation of the POI, excluding name tags.

Operators

operator ==(Object other) → bool
The equality operator.
override