TaskQueue class abstract

An abstract class that defines the interface for a queue that executes Future-returning closures in a controlled manner.

Implementers

Constructors

TaskQueue()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isCancelled → bool
no setter
metrics → TaskQueueMetrics
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add<T>(Future<T> closure()) → Future<T>
Adds a Future-returning closure to the queue.
cancel() → void
Cancels the queue.
clear() → void
Removes all pending tasks from the queue.
dispose() → void
Disposes the queue and releases any associated resources.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited