TaskQueueMetrics class

/////////////////////////////////////////////////////////////////////////// A class that holds performance metrics for a TaskQueue.

Constructors

TaskQueueMetrics({required String name})

Properties

averageProcessingTime → double
Returns average processing time per task in milliseconds
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
peakQueueSize ↔ int
getter/setter pair
processingTime → Stopwatch
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalErrors ↔ int
Returns total number of errors encountered
getter/setter pair
totalProcessed ↔ int
Returns total number of tasks processed
getter/setter pair

Methods

clear() → void
Resets all performance counters.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited