TaskQueueReport class

/////////////////////////////////////////////////////////////////////////// A report containing performance metrics for all registered task queues.

Constructors

TaskQueueReport()

Properties

enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
queueMetrics → List<TaskQueueMetrics>
A list of metrics for each registered queue.
no setter
registered → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
final
unregistered → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited