nearDistance property

double nearDistance
final

maximum distance in lat or long direction to treat two points as equal. This is used to find closed way where the first and last point are near but not equal.

Implementation

static final double nearDistance = 0.00005;