PerformanceStats class

/////////////////////////////////////////////////////////////////////////// Statistical analysis of performance metrics

Constructors

PerformanceStats({required int count, required int mean, required int median, required int min, required int max, required int p95, required int p99, required int standardDeviation, required int sum})
PerformanceStats.empty(String category)
factory

Properties

count → int
final
hashCode → int
The hash code for this object.
no setterinherited
max → int
final
mean → int
final
median → int
final
min → int
final
p95 → int
final
p99 → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
standardDeviation → int
final
sum → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited