EQUATORIAL_RADIUS property
WGS84 equatorial radius in meters.
The equatorial radius of Earth as defined by the WGS84 ellipsoid, which is the reference coordinate system used by GPS.
Implementation
static final double EQUATORIAL_RADIUS = 6378137.0;
WGS84 equatorial radius in meters.
The equatorial radius of Earth as defined by the WGS84 ellipsoid, which is the reference coordinate system used by GPS.
static final double EQUATORIAL_RADIUS = 6378137.0;